.. app documentation master file, created by
   sphinx-quickstart on Wed Oct 21 13:18:22 2009.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to django-formfield's documentation!
============================================

Contents:

.. toctree::
   :maxdepth: 2
   :glob:

   installation
   getting_started

   reference/index

Contributing
============

* `Source <https://github.com/jsoa/django-formfield>`_
* `Issues <https://github.com/jsoa/django-formfield/issues>`_


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

